@@ -32,10 +32,13 @@ class BaseConnect:
         self.subscribe_start()
         while True:
             if self.channel_listen is not None:
-                channels = self.channel_listen()
-                if channels is not None and len(channels) > 0:                
-                    if len(list(set(self.channels).intersection(set(channels)))) != len(channels):
-                        self.channels = channels
+                new_channels = self.channel_listen()
+                old_channels_str = [str(channel) for channel in self.channels]
+                new_channels_str = [str(channel) for channel in new_channels]
+                if new_channels_str is not None and len(new_channels_str) > 0:
+                    if len(list(set(old_channels_str) - set(new_channels_str))) == len(
+                            list(set(new_channels_str) - set(old_channels_str))) == 0:
+                        self.channels = new_channels
                         self.subscribe_restart()
             try:
                 res = self.ws.recv()
